@@ -7,12 +7,22 @@ from motordecalidad.utilities import *
 import datetime
 import time
 from motordecalidad.rules import *
-
-
-print("Motor de Calidad Version Release 1.9.15")
+import logging
+from azure.storage.blob import BlobServiceClient
+logging.basicConfig(filename='output.log',level=logging.INFO,format='%(asctime)s %(levelname)s %(message)s')
+conn_string = "DefaultEndpointsProtocol=https;AccountName=adlseu2edthdev001;AccountKey=T1RZsgj62zrRWcsYRW3QGr3+TEhtalj8o/fU3Zqmh4ef3TYxZw0P7+neqmgOPmbFOoVPZhLFT9GV+AStAj2YpA==;EndpointSuffix=core.windows.net"
+blob_service_client = BlobServiceClient.from_connection_string(conn_string)
+container_client = blob_service_client.get_container_client('metadata')
+blob_client = blob_service_client.get_blob_client(container='metadata', blob='output.log')
+def inform (message:str):
+    logging.info(message)
+    print(message)
+inform("Motor de Calidad Version Release 1.9.18")
 
 # Main function, Invokes all the parameters from the json, Optionally filters, starts the rule validation
 # Writes and returns the summary of the validation 
+
+
 def startValidation(inputspark,config,dfltPath=""):
     global spark
     global dbutils
@@ -20,12 +30,14 @@ def startValidation(inputspark,config,dfltPath=""):
     DefaultPath = dfltPath
     spark = inputspark
     dbutils = get_dbutils(spark)
-    print("Inicio de validacion")
+    inform("Inicio de validación")
     object,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData, email = extractParamsFromJson(config)
     filteredObject = applyFilter(object,filtered)
     registerAmount = filteredObject.count()
     validationData = validateRules(filteredObject,rules,registerAmount,entity,project,country,domain,subDomain,segment,area,error,dataDate,validData,finalData, email,output)
     writeDf(validationData, output)
+    with open('output.log', "rb") as data:
+        blob_client.upload_blob(data)
     return validationData
 
 # Function that extracts the information from de JSON File
@@ -52,12 +64,12 @@ def extractParamsFromJson(config):
     except:
         raise Exception("Error en la lectura del fichero")
     rules = data.get(JsonParts.Rules)
-    print("Extraccion de JSON completada")
+    inform("Extraccion de JSON completada")
     return entityDf,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData,email
 
 # Function that reads the input File
 def readDf(input):
-    print("inicio de lectura de informacion")
+    inform("inicio de lectura de informacion")
     type = input.get(JsonParts.Type)
     if type == "prod_csv":
         spark.conf.set(input.get(JsonParts.Account),input.get(JsonParts.Key))        
@@ -176,7 +188,7 @@ def writeDf(object:DataFrame,output):
                 object.coalesce(One).write.mode("overwrite").option("delimiter",str(output.get(JsonParts.Delimiter))).option("header",header).format("com.databricks.spark.csv").save(str(output.get(JsonParts.Path)))
         except:
             object.coalesce(One).write.mode("overwrite").option("delimiter",str(output.get(JsonParts.Delimiter))).option("header",header).format("com.databricks.spark.csv").save(str(output.get(JsonParts.Path)))
-    print("Se escribio en el blob")
+    inform("Se escribio en el blob")
 
 def createErrorData(object:DataFrame) :
     columnsList = object.columns
@@ -218,13 +230,13 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
         if rules[code].get(JsonParts.Fields) not in [0,["0"],"0"] :
             rulesNumber = rulesNumber + 1
             if code[0:3] == Rules.Pre_Requisites.code:
-                print("Inicializando regla de requisitos")
+                inform("Inicializando regla de requisitos")
                 columns = rules[code].get(JsonParts.Fields)
                 t = time.time()
                 validateRequisites(object,columns)
-                print("regla de requisitos: %s segundos" % (time.time() - t))
+                inform("regla de requisitos: %s segundos" % (time.time() - t))
             elif code[0:3] == Rules.NullRule.code:
-                print("Inicializando reglas de Nulos")
+                inform("Inicializando reglas de Nulos")
                 data:List = []
                 columns = rules[code].get(JsonParts.Fields)
                 threshold:int = rules[code].get(JsonParts.Threshold)
@@ -240,7 +252,7 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                             if write != "FALSE" :
                                 errorData = errorData.union(errorTotal)
                         rulesData.append(data)
-                        print("regla de nulos: %s segundos" % (time.time() - t))
+                        inform("regla de nulos: %s segundos" % (time.time() - t))
                 else:
                     for field in columns:
                         t = time.time()
@@ -255,7 +267,7 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         print("regla de nulos: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.DuplicatedRule.code:
-                print("Inicializando reglas de Duplicidad")
+                inform("Inicializando reglas de Duplicidad")
                 t = time.time()
                 testColumn = rules[code].get(JsonParts.Fields)
                 threshold:int = rules[code].get(JsonParts.Threshold)
@@ -268,10 +280,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                     if write != "FALSE" :
                         errorData = errorData.union(errorTotal)
                 rulesData.append(data)
-                print("regla de duplicados: %s segundos" % (time.time() - t))
+                inform("regla de duplicados: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.IntegrityRule.code:
-                print("Inicializando reglas de Integridad referencial")
+                inform("Inicializando reglas de Integridad referencial")
                 t = time.time()
                 referalData = rules[code].get(JsonParts.Input)
                 referenceDataFrame = readDf(referalData)
@@ -290,10 +302,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                     if write != "FALSE" :
                         errorData = errorData.union(errorTotal)
                 rulesData.append(data) 
-                print("regla de IR: %s segundos" % (time.time() - t))
+                inform("regla de IR: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.FormatDate.code:
-                print("Inicializando regla de formato")
+                inform("Inicializando regla de formato")
                 columnName = rules[code].get(JsonParts.Fields)
                 formatDate = rules[code].get(JsonParts.FormatDate)
                 threshold:int = rules[code].get(JsonParts.Threshold)
@@ -309,15 +321,15 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                             if write != "FALSE" :
                                 errorData = errorData.union(errorTotal)
                         rulesData.append(data) 
-                        print("regla de formato: %s segundos" % (time.time() - t))
+                        inform("regla de formato: %s segundos" % (time.time() - t))
                     else:
-                        print("Formato de fecha no reconocido por el motor")
-                        print("Los formatos permitidos son: ", PermitedFormatDate)
-                        print("El formato solicitado fue: ", formatDate)
-                        print("regla de formato: %s segundos" % (time.time() - t))
+                        inform("Formato de fecha no reconocido por el motor")
+                        inform("Los formatos permitidos son: ", PermitedFormatDate)
+                        inform("El formato solicitado fue: ", formatDate)
+                        inform("regla de formato: %s segundos" % (time.time() - t))
             
             elif code[0:3] == Rules.CatalogRule.code:
-                print("Inicializando regla de catálogo")
+                inform("Inicializando regla de catálogo")
                 columnName = rules[code].get(JsonParts.Fields)
                 listValues = rules[code].get(JsonParts.Values)
                 threshold:int = rules[code].get(JsonParts.Threshold)
@@ -332,10 +344,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de catalogo: %s segundos" % (time.time() - t))
+                    inform("regla de catalogo: %s segundos" % (time.time() - t))
             
             elif code[0:3] == Rules.RangeRule.code:
-                print("Inicializando regla de rango")
+                inform("Inicializando regla de rango")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold:int = rules[code].get(JsonParts.Threshold)
                 minRange = rules[code].get(JsonParts.MinRange)
@@ -352,10 +364,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de rango: %s segundos" % (time.time() - t))
+                    inform("regla de rango: %s segundos" % (time.time() - t))
             
             elif code[0:3] == Rules.ForbiddenRule.code:
-                print("Inicializando regla de caracteres prohibidos")
+                inform("Inicializando regla de caracteres prohibidos")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)
                 listValues = rules[code].get(JsonParts.Values)
@@ -371,10 +383,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != False :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de caracteres prohibidos: %s segundos" % (time.time() - t))
+                    inform("regla de caracteres prohibidos: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.Type.code:
-                print("Inicializando regla de tipo de dato")
+                inform("Inicializando regla de tipo de dato")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)
                 data_Type = rules[code].get(JsonParts.DataType) 
@@ -390,10 +402,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de caracteres tipo de dato: %s segundos" % (time.time() - t))
+                    inform("regla de caracteres tipo de dato: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.Composision.code:
-                print("Inicializando regla de composicion")
+                inform("Inicializando regla de composicion")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)
                 patialColumns = rules[code].get(JsonParts.Values)
@@ -409,10 +421,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de caracteres composicion: %s segundos" % (time.time() - t))
+                    inform("regla de caracteres composicion: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.LengthRule.code:
-                print("Inicializando regla de longitud")
+                inform("Inicializando regla de longitud")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)
                 minRange = rules[code].get(JsonParts.MinRange)
@@ -429,10 +441,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de longitud: %s segundos" % (time.time() - t))
+                    inform("regla de longitud: %s segundos" % (time.time() - t))
             
             elif code[0:3] == Rules.DataTypeRule.code:
-                print("Inicializando regla de tipo de dato parquet")
+                inform("Inicializando regla de tipo de dato parquet")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)
                 data_Type = rules[code].get(JsonParts.DataType)            
@@ -442,10 +454,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                     t = time.time()
                     data = validateDataType(object,field,registerAmount,entity,threshold,data_Type)
                     rulesData.append(data)
-                    print("regla de tipo de dato parquet: %s segundos" % (time.time() - t))
+                    inform("regla de tipo de dato parquet: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.NumericFormatRule.code:
-                print("Inicializando regla de tipo de formato numerico")
+                inform("Inicializando regla de tipo de formato numerico")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)   
                 maxInt = rules[code].get(JsonParts.MaxInt)
@@ -464,10 +476,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de formato numerico: %s segundos" % (time.time() - t))
+                    inform("regla de formato numerico: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.OperationRule.code:
-                print("Inicializando regla de tipo de operacion numerica")
+                inform("Inicializando regla de tipo de operacion numerica")
                 columnName = rules[code].get(JsonParts.Fields)
                 threshold = rules[code].get(JsonParts.Threshold)   
                 operator = rules[code].get(JsonParts.Operator)
@@ -486,10 +498,10 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                         if write != "FALSE" :
                             errorData = errorData.union(errorTotal)
                     rulesData.append(data)
-                    print("regla de operacion numerica: %s segundos" % (time.time() - t))
+                    inform("regla de operacion numerica: %s segundos" % (time.time() - t))
 
             elif code[0:3] == Rules.StatisticsResult.code:
-                print("Inicializando analisis exploratorio")
+                inform("Inicializando analisis exploratorio")
                 column = rules[code].get(JsonParts.Fields)
                 if column[0] == "*" :
                     res = measuresCentralTendency(object, object.columns, spark)
@@ -521,7 +533,7 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
         emailData = validationData.groupBy("CARACTERISTICA_REGLA").mean("PORCENTAJE_CALIDAD_OK")
         send_email(registerAmount,rulesNumber,output.get(JsonParts.Path),emailData,dataDateWidget,pais_widget,entity,email)
     except:
-        print("Se omite el envío de correo")
+        inform("Se omite el envío de correo")
     if errorData.count() > Zero:
         writeDf(errorData,error)
     return validationData.select(
