@@ -136,7 +136,8 @@ def validateCatalog(object:DataFrame,
     threshold: int):
     fieldsString = ','.join(listValues)
     dataRequirement = f"El atributo {entity}.{columnName}, debe tomar solo los valores {fieldsString}."
-    errorDf = object.filter(~col(columnName).cast("str").isin(listValues))
+    evaluatedColumn = col(columnName).cast("string")
+    errorDf = object.filter(~evaluatedColumn.isin(listValues))
 
     errorCount = errorDf.count()
     ratio = (One - errorCount/registerAmount) * OneHundred
